FieldRangeSlider class
Used to select a range of values within a set of values.
Constructors
-
FieldRangeSlider({String? activeColor, int? divisions, String? inactiveColor, String? labels, String? fieldLabel, bool? suffix, required double start, required double end, required double max, required double min, String? onChanged, String? OnChangeStart, String? OnChangeEnd, String? semanticFormatter, Map<
String, dynamic> ? sliderThemeData}) -
const
Properties
- activeColor → String?
-
final
- divisions → int?
-
final
- end → double
-
final
- fieldLabel → String?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inactiveColor → String?
-
final
- labels → String?
-
final
- max → double
-
final
- min → double
-
final
- onChanged → String?
-
final
- OnChangeEnd → String?
-
final
- OnChangeStart → String?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- semanticFormatter → String?
-
final
-
sliderThemeData
→ Map<
String, dynamic> ? -
one or more if
labelTextStyle, activeTrackColor, inactiveTrackColor, activeTickMarkColor, inactiveTickMarkColor, thumbColor, overlayColor, valueIndicatorColor, thumbShape, valueIndicatorShape, showValueIndicatorsliderComponentShape: one ofRectangularSliderThumbShape, RoundSliderThumbShape, RoundSliderTickMarkShape, RoundSliderOverlayShape, SliderComponentShapesliderTrackShape: onw odRectangularSliderTrackShape, RoundSliderTrackShaperangeSliderTickMarkShape: one ofRoundSliderTickMarkShape, RoundSliderTrackShaperangeSliderValueIndicatorShape: one ofPaddleSliderValueIndicatorShape, PaddleSliderValueIndicatorShaperangeSldertickMarkShape: one ofRoundSliderTickMarkShape, RoundSliderTrackShapedouble? trackHeight, Color? activeTrackColor, Color? inactiveTrackColor, Color? disabledActiveTrackColor, Color? disabledInactiveTrackColor, Color? activeTickMarkColor, Color? inactiveTickMarkColor, Color? disabledActiveTickMarkColor, Color? disabledInactiveTickMarkColor, Color? thumbColor, Color? overlappingShapeStrokeColor, Color? disabledThumbColor, Color? overlayColor, Color? valueIndicatorColor, SliderComponentShape? overlayShape, SliderTickMarkShape? tickMarkShape, SliderComponentShape? thumbShape, SliderTrackShape? trackShape, SliderComponentShape? valueIndicatorShape, RangeSliderTickMarkShape? rangeTickMarkShape, RangeSliderThumbShape? rangeThumbShape, RangeSliderTrackShape? rangeTrackShape, RangeSliderValueIndicatorShape? rangeValueIndicatorShape, ShowValueIndicator? showValueIndicator, TextStyle? valueIndicatorTextStyle, double? minThumbSeparation, Thumb? Function(TextDirection, RangeValues, double, Size, Size, double)? thumbSelector, MaterialStateProperty<MouseCursor?>? mouseCursor,final - start → double
-
final
- suffix → bool?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited